<?php

declare(strict_types=1);

namespace Drupal\Tests\entity_usage_updater\Functional;

use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\Tests\content_moderation\Traits\ContentModerationTestTrait;
use Drupal\Tests\paragraphs\FunctionalJavascript\ParagraphsTestBaseTrait;

/**
 * Tests the Link Remover form with future revisions.
 *
 * @group entity_usage_updater
 */
class FutureRevisionsParagraphsLinkRemoverFormTest extends FutureRevisionsLinkRemoverFormTest {
  use ParagraphsTestBaseTrait, ContentModerationTestTrait {
    ParagraphsTestBaseTrait::createEditorialWorkflow insteadof ContentModerationTestTrait;
    ParagraphsTestBaseTrait::createEditorialWorkflow as paragraphsCreateEditorialWorkflow;
    ContentModerationTestTrait::createEditorialWorkflow insteadof ParagraphsTestBaseTrait;
  }

  /**
   * {@inheritdoc}
   */
  const TEXT_FIELD = 'field_paragraphs[0][subform][field_paragraph_text][0][value]';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['paragraphs'];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->addParagraphsField('page', 'field_paragraphs', 'node');
    $this->addParagraphsType('test_paragraph');

    $field_storage = FieldStorageConfig::create([
      'field_name' => 'field_paragraph_text',
      'entity_type' => 'paragraph',
      'type' => 'text_long',
      'cardinality' => 1,
    ]);
    $field_storage->save();

    FieldConfig::create([
      'field_storage' => $field_storage,
      'bundle' => 'test_paragraph',
      'label' => 'Paragraph text field',
    ])->save();

    $form_display = \Drupal::service('entity_display.repository')->getFormDisplay('paragraph', 'test_paragraph');
    $page_display = \Drupal::service('entity_display.repository')->getViewDisplay('paragraph', 'test_paragraph');
    $form_display->setComponent('field_paragraph_text', ['type' => 'text_textarea']);
    $page_display->setComponent('field_paragraph_text', ['type' => 'text_default']);
    $form_display->save();
    $page_display->save();
  }

}
